show_json

Function show_json 

pub fn show_json(layout: &Layout, id: &str) -> Result<Value>
One issue as JSON, including its file and line range.

Errors

Returns an error if the corpus cannot be read, id is not in it, or the detail cannot be serialized.