load_recs

Function load_recs 

pub fn load_recs(layout: &Layout) -> Result<Vec<IssueRec>>
Snapshot every heading across every project, with the path detail and excerpt need.

Errors

Returns an error if a project directory cannot be listed or an issues.org cannot be read or parsed.