ping_report

Function ping_report 

pub fn ping_report(layout: &Layout, detail: Option<&str>) -> Result<String>
Append a manual event, waking pollers without touching an issues.org.

Errors

Returns an error if the event directory cannot be created, locked, or written.