pub struct PrioritySpec {
pub highest: char,
pub lowest: char,
pub default: char,
}Expand description
File-local priority cookie range (#+PRIORITIES: highest lowest default).
Org requires the highest cookie to have a lower ASCII value than the
lowest (A before C). The third token is the default when a heading
has no [#X].
Fields
highest: charHighest priority cookie (A in the house file).
lowest: charLowest priority cookie (C in the house file).
default: charCookie written when the heading has none.
Implementations