count

Function count 

pub fn count(
    layout: &Layout,
    project_filter: Option<&str>,
    state_filter: Option<&str>,
    ready_only: bool,
) -> Result<String>
The matching issue count and nothing else, for shell pipelines.

Errors

Returns an error if the corpus cannot be read.