cycles

Function cycles 

pub fn cycles(layout: &Layout) -> Result<String>
Cycles in the blocker graph, one per line, or a line saying there are none.

Errors

Returns an error if the corpus cannot be read.