graph_body

Function graph_body 

pub fn graph_body(
    layout: &Layout,
    project_filter: Option<&str>,
) -> Result<String>
The nodes and edges of the graph, without the enclosing digraph block.

Errors

Returns an error if the corpus cannot be read.