pub fn ping_report(layout: &Layout, detail: Option<&str>) -> Result<String>Expand description
Append a manual event, waking pollers without touching an issues.org.
Errors
Returns an error if the event directory cannot be created, locked, or written.