pub fn create(
layout: &Layout,
project: &str,
title: &str,
opts: CreateOpts<'_>,
) -> Result<String>Expand description
Append a new TODO issue to the project’s file and return the status text.
Errors
Returns an error if the priority is not A/B/C, a date does not parse,
parent is not a known org id, the id space is exhausted, or the file
cannot be locked or rewritten.