pub fn update_as(
layout: &Layout,
id: &str,
new_state: Option<&str>,
new_priority: Option<char>,
block_add: Option<&str>,
block_clear: Option<&str>,
identity: &str,
) -> Result<UpdateOutcome>Expand description
update with an explicit identity instead of crate::config::identity.
Errors
Returns an error if id is not in the corpus, the state or priority is
invalid, adding the blocker would cycle, or the file cannot be rewritten.