resolve_source

Function resolve_source 

pub fn resolve_source(router: &Router, source: &str) -> Option<Layout>
The tracker a board’s source names, when it is on this machine: the repository’s own tracker for self, a [layouts.*] name from the user’s config, else a path that holds a tracker.