pub fn impact(layout: &Layout, id: &str, depth: usize) -> Result<String>Expand description
Transitive issues waiting on this issue, limited to a bounded number of hops.
Errors
Returns an error if the corpus cannot be read, the blocker graph cannot be
built, or id is not in it.