pub fn list_projects(layout: &Layout) -> Result<Vec<String>>
Every project directory under the layout prefix that holds an issues.org.
issues.org
Returns an error if the projects directory exists but cannot be read.